==> question2answer-1.5-language-lt.zip: lt/qa-lang-emails.php <==
<?php
	
/*
	Question2Answer (c) Gideon Greenspan

	http://www.question2answer.org/

	
	File: qa-include/qa-lang-emails.php
	Version: See define()s at top of qa-include/qa-base.php
	Description: Language phrases for email notifications


	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'a_commented_body' => "Jūsų atsakymas ^site_title svetainėje turi naują komentarą nuo ^c_handle:\n\n^open^c_content^close\n\nJūsų atsakymas buvo:\n\n^open^c_context^close\n\nJūs galite atsakyti savo komentaru:\n\n^url\n\nDėkojame,\n\n^site_title",
		'a_commented_subject' => 'Jūsų ^site_title atsakymas turi naują komentarą',

		'a_followed_body' => "Jūsų atsakymas ^site_title svetainėje turi naują susijusį klausimą nuo ^q_handle:\n\n^open^q_title^close\n\nJūsų atsakymas buvo:\n\n^open^a_content^close\n\nPaspauskite žemiau, kad atsakytumėte į naująjį klausimą:\n\n^url\n\nDėkojame,\n\n^site_title",
		'a_followed_subject' => 'Jūsų ^site_title atsakymas turi susijusį klausimą',

		'a_selected_body' => "Sveikiname! Jūsų atsakymas ^site_title svetainėje buvo pasirinktas kaip geriausias vartotojo ^s_handle:\n\n^open^a_content^close\n\nKlausimas buvo:\n\n^open^q_title^close\n\nPaspauskite žemiau, kad pamatytumėte atsakymą:\n\n^url\n\nDėkojame,\n\n^site_title",
		'a_selected_subject' => 'Jūsų ^site_title atsakymas buvo pasirinktas kaip geriausias!',

		'c_commented_body' => "Vartotojas ^c_handle parašė po jūsų komentaru svetainėje ^site_title:\n\n^open^c_content^close\n\nDiskusijos tema:\n\n^open^c_context^close\n\nJūs galit atsakyti pridėdami naują komentarą:\n\n^url\n\nDėkojame,\n\n^site_title",
		'c_commented_subject' => 'Buvo pakomentuota po jūsų ^site_title komentaru',

		'confirm_body' => "Prašom paspausti žemiau esančią nuorodą, kad patvirtintumėte savo el. pašto adresą svetainėje ^site_title.\n\n^url\n\nDėkojame,\n^site_title",
		'confirm_subject' => '^site_title - el. pašto patvirtinimas',

		'feedback_body' => "Komentarai:\n^message\n\nVardas:\n^name\n\nEl. paštas:\n^email\n\nAnkstesnis puslapis:\n^previous\n\nVartotojas:\n^url\n\nIP adresas:\n^ip\n\nNaršyklė:\n^browser",
		'feedback_subject' => '^ atsiliepimas',

		'flagged_body' => "Vartotojo ^p_handle įrašas sulaukė ^flags:\n\n^open^p_context^close\n\nPaspauskite žemiau, kad pamatytumėte įrašą:\n\n^url\n\nDėkojame,\n\n^site_title",
		'flagged_subject' => '^site_title turi įrašą, pažymėtą kaip netinkamą',

		'moderate_body' => "Vartotojo ^p_handle įrašui reikia jūsų patvirtinimo:\n\n^open^p_context^close\n\nPaspauskite nuorodą žemiau, kad patvirtintumėte arba atmestumėte įrašą:\n\n^url\n\nDėkojame,\n\n^site_title",
		'moderate_subject' => '^site_title moderavimas',

		'new_password_body' => "Jūsų naujas svetainės ^site_title slaptažodis yra parodytas žemiau.\n\nSlaptažodis: ^password\n\nRekomenduojama pasikeisti šį slaptažodį vos tik prisijungus prie svetainės.\n\nDėkojame,\n^site_title\n^url",
		'new_password_subject' => '^site_title - jūsų naujas slaptažodis',

		'private_message_body' => "Jums buvo atsiųsta privati žinutė nuo vartotojo ^f_handle svetainėje ^site_title:\n\n^open^message^close\n\n^moreDėkojame,\n\n^site_title\n\n\nJei norite blokuoti privačias žinutes, aplankykite savo paskyros puslapį:\n^a_url",
		'private_message_info' => "Daugiau informacijos apie ^f_handle:\n\n^url\n\n",
		'private_message_reply' => "Paspauskite žemiau, atsakytumėte vartotojui ^f_handle privačia žinute:\n\n^url\n\n",
		'private_message_subject' => 'Žinutė nuo ^f_handle svetainėje ^site_title',

		'q_answered_body' => "Jūsų klausimas svetainėje ^site_title buvo atsakytas vartotojo ^a_handle:\n\n^open^a_content^close\n\nJūsų klausimas:\n\n^open^q_title^close\n\nJei manote, kad atsakymas yra geras, tai jūs galite jį pasirinkti kaip geriausią:\n\n^url\n\nDėkojame,\n\n^site_title",
		'q_answered_subject' => 'Jūsų klausimas svetainėje ^site_title buvo atsakytas',

		'q_commented_body' => "Jūsų klausimas svetainėje ^site_title turi naują komentarą iš vartotojo ^c_handle:\n\n^open^c_content^close\n\nJūsų klausimas buvo:\n\n^open^c_context^close\n\nJūs galite atsakyti pridėdami savo komentarą:\n\n^url\n\nDėkojame,\n\n^site_title",
		'q_commented_subject' => 'Jūsų klausimas svetainėje ^site_title turi naują komentarą',

		'q_posted_body' => "Naujas klausimas buvo paklaustas vartotojo ^q_handle:\n\n^open^q_title\n\n^q_content^close\n\nPaspauskite šią nuorodą tam, kad peržiūrėtumėte klausimą:\n\n^url\n\nDėkojame,\n\n^site_title",
		'q_posted_subject' => '^site_title turi naują klausimą',

		'reset_body' => "Prašom paspausti žemiau esančią nuorodą tam, kad atstatytumėte savo slaptažodį svetainėje ^site_title.\n\n^url\n\nArba įveskite žemiau užrašytą kodą į nurodytą laukelį.\n\nKodas: ^code\n\nJei jūs neprašėte atstatyti savo slaptažodžio, galite ignoruoti šią žinutę.\n\nDėkojame,\n^site_title",
		'reset_subject' => '^site_title - užmiršto slaptažodžio atstatymas',

		'to_handle_prefix' => "^,\n\n",

		'welcome_body' => "Dėkojame, kad registruojatės svetainėje ^site_title.\n\n^custom^confirmJūsų prisijungimo informacija:\n\nEl. paštas: ^email\nSlaptažodis: ^password\n\nPrašom laikyti šią informaciją saugioje vietoje ateičiai.\n\nDėkojame,\n\n^site_title\n^url",
		'welcome_confirm' => "Prašom paspausti nuorodą žemiau tam, kad patvirtintumėte savo el. pašto adresą.\n\n^url\n\n",
		'welcome_subject' => 'Sveiki prisijungę prie svetainės ^site_title!',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/

==> question2answer-1.7-language-lt.zip: lt/qa-lang-emails.php <==
<?php
/*
	Question2Answer by Gideon Greenspan and contributors
	http://www.question2answer.org/

	File: qa-include/qa-lang-emails.php
	Description: Language phrases for email notifications


	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'a_commented_body' => "Jūsų atsakymas ^site_title svetainėje turi naują komentarą nuo ^c_handle:\n\n^open^c_content^close\n\nJūsų atsakymas buvo:\n\n^open^c_context^close\n\nJūs galite atsakyti savo komentaru:\n\n^url\n\nDėkojame,\n\n^site_title",
		'a_commented_subject' => 'Jūsų ^site_title atsakymas turi naują komentarą',

		'a_followed_body' => "Jūsų atsakymas ^site_title svetainėje turi naują susijusį klausimą nuo ^q_handle:\n\n^open^q_title^close\n\nJūsų atsakymas buvo:\n\n^open^a_content^close\n\nPaspauskite žemiau, kad atsakytumėte į naująjį klausimą:\n\n^url\n\nDėkojame,\n\n^site_title",
		'a_followed_subject' => 'Jūsų ^site_title atsakymas turi susijusį klausimą',

		'a_selected_body' => "Sveikiname! Jūsų atsakymas ^site_title svetainėje buvo pasirinktas kaip geriausias vartotojo ^s_handle:\n\n^open^a_content^close\n\nKlausimas buvo:\n\n^open^q_title^close\n\nPaspauskite žemiau, kad pamatytumėte atsakymą:\n\n^url\n\nDėkojame,\n\n^site_title",
		'a_selected_subject' => 'Jūsų ^site_title atsakymas buvo pasirinktas kaip geriausias!',

		'c_commented_body' => "Vartotojas ^c_handle parašė po jūsų komentaru svetainėje ^site_title:\n\n^open^c_content^close\n\nDiskusijos tema:\n\n^open^c_context^close\n\nJūs galit atsakyti pridėdami naują komentarą:\n\n^url\n\nDėkojame,\n\n^site_title",
		'c_commented_subject' => 'Buvo pakomentuota po jūsų ^site_title komentaru',

		'confirm_body' => "Prašom paspausti žemiau esančią nuorodą, kad patvirtintumėte savo el. pašto adresą svetainėje ^site_title.\n\n^url\n\nDėkojame,\n^site_title",
		'confirm_subject' => '^site_title - el. pašto patvirtinimas',

		'feedback_body' => "Komentarai:\n^message\n\nVardas:\n^name\n\nEl. paštas:\n^email\n\nAnkstesnis puslapis:\n^previous\n\nVartotojas:\n^url\n\nIP adresas:\n^ip\n\nNaršyklė:\n^browser",
		'feedback_subject' => '^ atsiliepimas',

		'flagged_body' => "Vartotojo ^p_handle įrašas sulaukė ^flags:\n\n^open^p_context^close\n\nPaspauskite žemiau, kad pamatytumėte įrašą:\n\n^url\n\nPaspauskite žemiau, kad peržiūrėtumėte visus įrašus pažymėtus kaip netinkamus:\n\n^a_url\n\n\nDėkojame,\n\n^site_title",
		'flagged_subject' => '^site_title turi įrašą, pažymėtą kaip netinkamą',

		'moderate_body' => "Vartotojo ^p_handle įrašui reikia jūsų patvirtinimo:\n\n^open^p_context^close\n\nPaspauskite nuorodą žemiau, kad patvirtintumėte arba atmestumėte įrašą:\n\n^url\n\nPaspauskite žemiau jei norite peržiūrėti visus įrašus eilėje:\n\n^a_url\n\n\nDėkojame,\n\n^site_title",
		'moderate_subject' => '^site_title moderavimas',

		'new_password_body' => "Jūsų naujas svetainės ^site_title slaptažodis yra parodytas žemiau.\n\nSlaptažodis: ^password\n\nRekomenduojama pasikeisti šį slaptažodį vos tik prisijungus prie svetainės.\n\nDėkojame,\n^site_title\n^url",
		'new_password_subject' => '^site_title - jūsų naujas slaptažodis',

		'private_message_body' => "Jums buvo atsiųsta privati žinutė nuo vartotojo ^f_handle svetainėje ^site_title:\n\n^open^message^close\n\n^moreDėkojame,\n\n^site_title\n\n\nJei norite blokuoti privačias žinutes, aplankykite savo paskyros puslapį:\n^a_url",
		'private_message_info' => "Daugiau informacijos apie ^f_handle:\n\n^url\n\n",
		'private_message_reply' => "Paspauskite žemiau, atsakytumėte vartotojui ^f_handle privačia žinute:\n\n^url\n\n",
		'private_message_subject' => 'Žinutė nuo ^f_handle svetainėje ^site_title',

		'q_answered_body' => "Jūsų klausimas svetainėje ^site_title buvo atsakytas vartotojo ^a_handle:\n\n^open^a_content^close\n\nJūsų klausimas:\n\n^open^q_title^close\n\nJei manote, kad atsakymas yra geras, tai jūs galite jį pasirinkti kaip geriausią:\n\n^url\n\nDėkojame,\n\n^site_title",
		'q_answered_subject' => 'Jūsų klausimas svetainėje ^site_title buvo atsakytas',

		'q_commented_body' => "Jūsų klausimas svetainėje ^site_title turi naują komentarą iš vartotojo ^c_handle:\n\n^open^c_content^close\n\nJūsų klausimas buvo:\n\n^open^c_context^close\n\nJūs galite atsakyti pridėdami savo komentarą:\n\n^url\n\nDėkojame,\n\n^site_title",
		'q_commented_subject' => 'Jūsų klausimas svetainėje ^site_title turi naują komentarą',

		'q_posted_body' => "Naujas klausimas buvo paklaustas vartotojo ^q_handle:\n\n^open^q_title\n\n^q_content^close\n\nPaspauskite šią nuorodą tam, kad peržiūrėtumėte klausimą:\n\n^url\n\nDėkojame,\n\n^site_title",
		'q_posted_subject' => '^site_title turi naują klausimą',

		'remoderate_body' => "Vartotojo ^p_handle pataisytas įrašas reikalauja jūsų pakartotinio patvirtinimo:\n\n^open^p_context^close\n\nPaspauskite nuorodą žemiau, kad patvirtintumėte arba atmestumėte paredaguotą įrašą:\n\n^url\n\n\nPaspauskite žemiau jei norite peržiūrėti visus įrašus eilėje:\n\n^a_url\n\n\nDėkojame,\n\n^site_title",
		'remoderate_subject' => '^site_title moderavimas',
		
		'reset_body' => "Prašom paspausti žemiau esančią nuorodą tam, kad atstatytumėte savo slaptažodį svetainėje ^site_title.\n\n^url\n\nArba įveskite žemiau užrašytą kodą į nurodytą laukelį.\n\nKodas: ^code\n\nJei jūs neprašėte atstatyti savo slaptažodžio, galite ignoruoti šią žinutę.\n\nDėkojame,\n^site_title",
		'reset_subject' => '^site_title - užmiršto slaptažodžio atstatymas',

		'to_handle_prefix' => "^,\n\n",
		
		'u_registered_body' => "Sistemoje prisiregistravo naujas vartotojas ^u_handle.\n\nPaspauskite žemiau, kad peržiūrėtumėte vartotojo profilį:\n\n^url\n\nDėkojame,\n\n^site_title",
		'u_registered_subject' => '^site_title turi naują prisiregistravusį vartotoją',
		'u_to_approve_body' => "Sistemoje prisiregistravo naujas vartotojas ^u_handle.\n\nPaspauskite žemiau, kad patvirtintumėte šį vartotoją:\n\n^url\n\nPaspauskite žemiau, kad peržiūrėtumėte visus vartotojus laukiančius patvirtinimo:\n\n^a_url\n\nDėkojame,\n\n^site_title",

		'u_approved_body' => "Jūs galite peržiūrėti savo naują vartotojo profilį čia:\n\n^url\n\nDėkojame,\n\n^site_title",
		'u_approved_subject' => 'Jūsų ^site_title vartotojas buvo patvirtintas',

		'wall_post_body' => "^f_handle sukūrė įrašą ant jūsų vartotojų sienos ^site_title:\n\n^open^post^close\n\nJūs galite atsakyti į įrašą čia:\n\n^url\n\nDėkojame,\n\n^site_title",
		'wall_post_subject' => 'Įrašas ant ^site_title sienos',

		'welcome_body' => "Dėkojame, kad registruojatės svetainėje ^site_title.\n\n^custom^confirm Jūsų prisijungimo informacija:\n\nVartotojo vardas: ^handle\nEl. paštas: ^email\nSlaptažodis: ^password\n\nPrašome laikyti šią informaciją saugioje vietoje ateičiai.\n\nDėkojame,\n\n^site_title\n^url",
		'welcome_confirm' => "Prašom paspausti nuorodą žemiau tam, kad patvirtintumėte savo el. pašto adresą.\n\n^url\n\n",
		'welcome_subject' => 'Sveiki prisijungę prie svetainės ^site_title!',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/
